@@ -4,6 +4,9 @@ import gzip
 import numpy as np
 import logging
 
+class NoLinearProjectionException(Exception):
+    pass
+
 class Position(object):
     """ Represents a position  in the graph
 
@@ -550,6 +553,55 @@ class Interval(BaseInterval):
         from .indexedinterval import NumpyIndexedInterval
         return NumpyIndexedInterval.from_interval(self)
 
+    def to_linear_offsets(self, linear_path):
+        intersecting_nodes = set(self.region_paths).intersection(linear_path.nodes_in_interval())
+
+        intersecting_nodes = sorted(list(intersecting_nodes))
+
+        if len(intersecting_nodes) == 0:
+            raise NoLinearProjectionException("No linear exception for interval %s" % self)
+
+        first_node = intersecting_nodes[0]
+        start_offset = 0
+        if first_node == self.region_paths[0]:
+            start_offset = self.start_position.offset
+
+        last_node = intersecting_nodes[-1]
+        end_offset = 0
+        if last_node == self.region_paths[-1]:
+            end_offset = self.end_position.offset
+
+        linear_start_pos = linear_path.get_offset_at_node(first_node) + start_offset
+        linear_end_pos = linear_path.get_offset_at_node(last_node) + end_offset
+        return linear_start_pos, linear_end_pos
+
+    def to_linear_offsets2(self, linear_path):
+        nodes_in_linear = linear_path.nodes_in_interval()
+        first_node = self.region_paths[0]
+
+        if first_node in nodes_in_linear:
+            start = linear_path.get_offset_at_position(self.start_position)
+        else:
+            prev_on_linear = set([-node for node in self.graph.reverse_adj_list[-first_node]]).intersection(nodes_in_linear)
+            if len(prev_on_linear) < 1:
+                raise NoLinearProjectionException()
+            #assert len(prev_on_linear) >= 1, "Node %d has either none or multiple previous nodes on linear path (n=%d)" % (first_node, len(prev_on_linear))
+            prev_on_linear = list(prev_on_linear)[0]
+            start = linear_path.get_offset_at_node(prev_on_linear) + self.graph.node_size(prev_on_linear) + self.start_position.offset
+
+        last_node = self.region_paths[-1]
+        if last_node == first_node or last_node in nodes_in_linear:
+            end = start + self.length()
+        else:
+            prev_on_linear = set([-node for node in self.graph.reverse_adj_list[-last_node]]).intersection(nodes_in_linear)
+            if len(prev_on_linear) < 1:
+                raise NoLinearProjectionException()
+            #assert len(prev_on_linear) >= 1, "Node %d has either none or multiple previous nodes on linear path (n=%d)" % (last_node, len(prev_on_linear))
+            prev_on_linear = list(prev_on_linear)[0]
+            end = linear_path.get_offset_at_node(prev_on_linear) + self.graph.node_size(prev_on_linear) + self.end_position.offset
+
+        return int(start), int(end)
+
 
 class IntervalCollection(object):
     interval_class = Interval
